pub struct SocketRights(/* private fields */);Expand description
Socket rights. Overnet treats rights as per-object type, to reduce the space of things that can be communicated over its wire format. Transfer rights are always assumed present.
Implementations
Sourceimpl SocketRights
impl SocketRights
pub const READ: SocketRights
pub const WRITE: SocketRights
Sourceimpl SocketRights
impl SocketRights
Sourcepub const fn empty() -> SocketRights
pub const fn empty() -> SocketRights
Get a flags value with all bits unset.
Sourcepub const fn all() -> SocketRights
pub const fn all() -> SocketRights
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SocketRights>
pub const fn from_bits(bits: u32) -> Option<SocketRights>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SocketRights
pub const fn from_bits_truncate(bits: u32) -> SocketRights
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SocketRights
pub const fn from_bits_retain(bits: u32) -> SocketRights
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SocketRights>
pub fn from_name(name: &str) -> Option<SocketRights>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SocketRights) -> bool
pub const fn intersects(&self, other: SocketRights) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SocketRights) -> bool
pub const fn contains(&self, other: SocketRights) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SocketRights)
pub fn insert(&mut self, other: SocketRights)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SocketRights)
pub fn remove(&mut self, other: SocketRights)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SocketRights)
pub fn toggle(&mut self, other: SocketRights)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SocketRights, value: bool)
pub fn set(&mut self, other: SocketRights, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SocketRights) -> SocketRights
pub const fn intersection(self, other: SocketRights) -> SocketRights
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SocketRights) -> SocketRights
pub const fn union(self, other: SocketRights) -> SocketRights
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SocketRights) -> SocketRights
pub const fn difference(self, other: SocketRights) -> SocketRights
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SocketRights) -> SocketRights
pub const fn symmetric_difference(self, other: SocketRights) -> SocketRights
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SocketRights
pub const fn complement(self) -> SocketRights
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SocketRights
impl SocketRights
Sourcepub const fn iter(&self) -> Iter<SocketRights> ⓘ
pub const fn iter(&self) -> Iter<SocketRights> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SocketRights> ⓘ
pub const fn iter_names(&self) -> IterNames<SocketRights> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.